summaryrefslogtreecommitdiffstats
path: root/drivers/net/wireless/rt2x00/rt2x00queue.h
diff options
context:
space:
mode:
authorIvo van Doorn2010-11-06 15:48:05 +0100
committerJohn W. Linville2010-11-15 19:26:32 +0100
commit813f0339dd739c48607f12dac79ec26c61874226 (patch)
treef758f461c71bdc176627af20692b9369ddb11f96 /drivers/net/wireless/rt2x00/rt2x00queue.h
parentrt2x00: checkpatch.pl error fixes for rt73usb.c (diff)
downloadkernel-qcow2-linux-813f0339dd739c48607f12dac79ec26c61874226.tar.gz
kernel-qcow2-linux-813f0339dd739c48607f12dac79ec26c61874226.tar.xz
kernel-qcow2-linux-813f0339dd739c48607f12dac79ec26c61874226.zip
rt2x00: Rename queue->lock to queue->index_lock
The queue->lock is only used to protect the index numbers. Rename the lock accordingly. Signed-off-by: Ivo van Doorn <IvDoorn@gmail.com> Acked-by: Gertjan van Wingerde <gwingerde@gmail.com> Signed-off-by: John W. Linville <linville@tuxdriver.com>
Diffstat (limited to 'drivers/net/wireless/rt2x00/rt2x00queue.h')
-rw-r--r--drivers/net/wireless/rt2x00/rt2x00queue.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/net/wireless/rt2x00/rt2x00queue.h b/drivers/net/wireless/rt2x00/rt2x00queue.h
index 64c00e2ab716..29b051ac6401 100644
--- a/drivers/net/wireless/rt2x00/rt2x00queue.h
+++ b/drivers/net/wireless/rt2x00/rt2x00queue.h
@@ -398,7 +398,7 @@ enum queue_index {
* @entries: Base address of the &struct queue_entry which are
* part of this queue.
* @qid: The queue identification, see &enum data_queue_qid.
* @lock: Spinlock to protect index handling. Whenever @index, @index_done or
* @index_crypt needs to be changed this lock should be grabbed to prevent
* index corruption due to concurrency.
* @count: Number of frames handled in the queue.
@@ -422,7 +422,7 @@ struct data_queue {
enum data_queue_qid qid;
- spinlock_t lock;
+ spinlock_t index_lock;
unsigned int count;
unsigned short limit;
unsigned short threshold;
@@ -398,7 +398,7 @@ enum queue_index {
* part of this queue.
* @qid: The queue identification, see &enum data_queue_qid.
- * @lock: Spinlock to protect index handling. Whenever @index, @index_done or
+ * @index_lock: Spinlock to protect index handling. Whenever @index, @index_done or
* @index_crypt needs to be changed this lock should be grabbed to prevent
* index corruption due to concurrency.